@@ -479,7 +479,7 @@ class CloudPods:
                 log.warning(f"ip_addr do not in server['server']['nics'][0], server['server']['nics'][0] is {server['server']['nics'][0]}")
                 return None
             if not network_id:
-                server_ip=["server"]["nics"][0]["ip_addr"]
+                server_ip=server["server"]["nics"][0]["ip_addr"]
                 return server_ip
             else:
                 for nic in server["server"]["nics"]:
@@ -751,6 +751,8 @@ class CloudPods:
 
 if __name__ == '__main__':
     cloudpods = CloudPods('https://10.30.18.1:30500/v3','admin','jSj@2008')
+    ip=cloudpods.get_server_ip("94914d36-2586-4eb3-8c91-0aac5c25e609")
+    print(ip)
     # server_ip = cloudpods.get_server_ip("e3b76ec7-c4f9-4065-8ce2-9d833b51368c")
     # print(server_ip)
     # cloudpods = CloudPods('https://10.240.30.110:30500/v3', 'admin', 'jSj@2008')
@@ -762,8 +764,8 @@ if __name__ == '__main__':
     #     if elem["id"]=="5d6dfb67-db25-43d2-8057-116769fb3abf":
     #         print(elem)
     # rs = cloudpods.get_can_deploy_server_host_num("x86_64","bios")
-    rs = cloudpods.modify_src_check("6fdbaa06-191f-4103-8571-fd65281d3b70","off","off")
-    print(rs)
+    # rs = cloudpods.modify_src_check("6fdbaa06-191f-4103-8571-fd65281d3b70","off","off")
+    # print(rs)
     # print(len(rs))
     # print(rs[0])
     # rs=cloudpods.get_server_status("b43ba471-471a-44c1-8753-a7b8a9ead05c")
